from .DataApiQuery import (
    DataApiQuery,
    SamplingPeriod,
    REQUEST_LIMIT,
)
from pydantic import ConfigDict, model_validator, field_validator, ValidationError
from typing import Optional
import logging
from fastapi import HTTPException

logging.basicConfig(
    level=logging.INFO,
    format="%(asctime)s - %(levelname)s - %(message)s",
)

"""This class inherits all the fields and validation on DataApiQuery and adds
the fields input_sampling_period and output_sampling_period."""


class FilterApiQuery(DataApiQuery):
    model_config = ConfigDict(extra="forbid")

    input_sampling_period: Optional[SamplingPeriod] = None

    @model_validator(mode="after")
    def validate_sample_size(self):
        if self.sampling_period is None:
            # Log a warning indicating that the sampling period is missing
            logging.warning(
                "Sampling period is None. Please provide a valid Sampling Period."
            )

        else:
            # Calculate the number of samples based on the input sampling period
            samples = int(
                len(self.elements)
                * (self.endtime - self.starttime)
                / self.sampling_period
            )

            # Validate the request size
            if samples > REQUEST_LIMIT:
                raise ValueError(f"Request exceeds limit ({samples} > {REQUEST_LIMIT})")

        return self
